@@ -164,7 +164,7 @@ impl Web3 {
             topics: Some(final_topics),
         };
 
-        Ok(self.eth_get_logs(new_filter).await?)
+        self.eth_get_logs(new_filter).await
     }
 
     /// Checks for multiple events as defined by arbitrary user input over a block range. If no ending block is provided
@@ -202,6 +202,6 @@ impl Web3 {
             topics: Some(final_topics),
         };
 
-        Ok(self.eth_get_logs(new_filter).await?)
+        self.eth_get_logs(new_filter).await
     }
 }
