@@ -11,8 +11,10 @@ extern crate lazy_static;
 pub mod amm;
 pub mod client;
 mod erc20_utils;
+mod erc721_utils;
 pub mod eth_wrapping;
 mod event_utils;
+pub mod gas_estimator;
 pub mod jsonrpc;
 mod mem;
 pub mod types;
